{% extends "admin/base.html" %}
{% load i18n admin_static %}

{% block extrastyle %}
<link rel="stylesheet" href="{% static "medicine_utils/admin/style.css" %}">
{% endblock %}

{% block extrahead %}
{% include "medicine_utils/add_js.html" %}
{{ block.super }}
{% endblock %}

{% block nav-global %}{% endblock %}

{% block userlinks %}
    {% if request.user.is_superuser %}
        {% if user.is_active and user.is_staff %}
        {% url 'django-admindocs-docroot' as docsroot %}
        {% if docsroot %}
            <a href="{{ docsroot }}">{% trans 'Documentation' %}</a> /
        {% endif %}
        <a href="{% url 'admin:constance_config_changelist' %}">Настройки</a> /
        {% endif %}
    {% endif %}
    {% if site_url %}
        <a href="{{ site_url }}">Открыть сайт</a> /
    {% endif %}
    {% if user.has_usable_password %}
        <a href="{% url 'admin:password_change' %}">{% trans 'Change password' %}</a> /
    {% endif %}
    <a href="{% url 'admin:logout' %}">{% trans 'Log out' %}</a>
{% endblock %}
